Telemetry - Blueye SDK

Skip to content

# Telemetry

## `` telemetry

Classes:

- `AltitudeTel` –

  Receive the current altitude of the drone.

- `AquaTrollProbeMetadataTel` –

  Metadata from the In-Situ Aqua Troll probe's common registers

- `AquaTrollSensorMetadataTel` –

  Metadata from a single sensor from In-Situ Aqua Troll probe

- `AquaTrollSensorParametersTel` –

  Single sensor from In-Situ Aqua Troll probe

- `AttitudeTel` –

  Receive the current attitude of the drone.

- `BatteryBQ40Z50Tel` –

  Receive detailed information about a battery using the

- `BatteryTel` –

  Receive essential information about the battery status.

- `CPUInfoTel` –

  Information about cpu and memory usage.

- `CPUTemperatureTel` –

  Drone CPU temperature

- `CalibratedImuTel` –

  Calibrated IMU data.

- `CalibrationStateTel` –

  Calibration state used for calibration routine.

- `CanisterBottomHumidityTel` –

  Receive humidity information from the bottom canister.

- `CanisterBottomTemperatureTel` –

  Receive temperature information from the bottom canister.

- `ConnectedClientsTel` –

  List of connected clients telemetry message.

- `ControlForceTel` –

  Control force in all directions.

- `ControlModeTel` –

  Receive the current state of the control system.

- `ControllerHealthTel` –

  Controller health indicating the load of the controller, used

- `CpProbeTel` –

  Cathodic Protection Potential probe telemetry message

- `DataStorageSpaceTel` –

  Data storage info.

- `DepthTel` –

  Measurement of the drones position relative to the sea

- `DiveTimeTel` –

  Receive the dive time of the drone.

- `DroneInfoTel` –

  Receive metadata and information about the connected drone.

- `DroneTimeTel` –

  Receive time information from the drone.

- `DvlVelocityTel` –

  Dvl raw sensor data.

- `ErrorFlagsTel` –

  Receive currently set error flags.

- `ForwardDistanceTel` –

  Distance to an object in front of the drone when a 1D pinger

- `GenericServoTel` –

  State of a generic servo.

- `GuestPortCurrentTel` –

  GuestPort current readings.

- `GuestPortLightsTel` –

  Receive the status of any guest port lights connected to the

- `Imu1Tel` –

  Raw IMU data from IMU 1

- `Imu2Tel` –

  Raw IMU data from IMU 2

- `IperfTel` –

  Iperf indicates the available bandwidth on the tether from

- `LaserTel` –

  Receive the status of any lasers connected to the drone.

- `LightsTel` –

  Receive the status of the main lights of the drone.

- `MedusaSpectrometerDataTel` –

  Medusa gamma ray sensor spectrometer data.

- `MissionStatusTel` –

  Mission status from the mission supervisor.

- `MultibeamConfigTel` –

  Multibeam sonar config.

- `MultibeamDiscoveryTel` –

  Multibeam sonar status message.

- `MultibeamPingTel` –

  Multibeam sonar ping data.

- `MultibeamServoTel` –

  State of the servo installed in the multibeam.

- `NStreamersTel` –

  Number of connected clients streaming video.

- `NotificationTel` –

  Notification from the control system.

- `PilotGPSPositionTel` –

  Pilot position (originating from device GPS) for logging.

- `PositionEstimateTel` –

  Position estimate of the drone if a DVL or a positioning

- `RecordStateTel` –

  Record state from the drone.

- `ReferenceAutoPilotTel` –

  Reference for the auto pilot when a mission is active.

- `ReferenceTel` –

  Reference signals indicating desired states.

- `ThicknessGaugeTel` –

  Thickness gauge measurement telemetry message.

- `TiltAngleTel` –

  Tilt angle state on main camera.

- `TiltStabilizationTel` –

  Tilt stabilization state.

- `TimeLapseStateTel` –

  Time-lapse state from the drone.

- `VideoStorageSpaceTel` –

  Video storage info.

- `WaterTemperatureTel` –

  Water temperature from the depth sensor.

### `` AltitudeTel

Receive the current altitude of the drone.

#### `` altitude `class-attribute` `instance-attribute`

    altitude: Altitude = Field(
        MESSAGE, number=1, message=Altitude
    )

### `` AquaTrollProbeMetadataTel

Metadata from the In-Situ Aqua Troll probe's common registers

#### `` probe `class-attribute` `instance-attribute`

    probe: AquaTrollProbeMetadata = Field(
        MESSAGE, number=1, message=AquaTrollProbeMetadata
    )

### `` AquaTrollSensorMetadataTel

Metadata from a single sensor from In-Situ Aqua Troll probe

#### `` sensors `class-attribute` `instance-attribute`

    sensors: AquaTrollSensorMetadataArray = Field(
        MESSAGE, number=1, message=AquaTrollSensorMetadataArray
    )

### `` AquaTrollSensorParametersTel

Single sensor from In-Situ Aqua Troll probe

#### `` sensors `class-attribute` `instance-attribute`

    sensors: AquaTrollSensorParametersArray = Field(
        MESSAGE,
        number=1,
        message=AquaTrollSensorParametersArray,
    )

### `` AttitudeTel

Receive the current attitude of the drone.

#### `` attitude `class-attribute` `instance-attribute`

    attitude: Attitude = Field(
        MESSAGE, number=1, message=Attitude
    )

### `` BatteryBQ40Z50Tel

Receive detailed information about a battery using the BQ40Z50 battery management system.

#### `` battery `class-attribute` `instance-attribute`

    battery: BatteryBQ40Z50 = Field(
        MESSAGE, number=1, message=BatteryBQ40Z50
    )

### `` BatteryTel

Receive essential information about the battery status.

#### `` battery `class-attribute` `instance-attribute`

    battery: Battery = Field(MESSAGE, number=1, message=Battery)

### `` CPUInfoTel

Information about cpu and memory usage.

#### `` cpu_info `class-attribute` `instance-attribute`

    cpu_info: CPUInfo = Field(
        MESSAGE, number=1, message=CPUInfo
    )

### `` CPUTemperatureTel

Drone CPU temperature

#### `` temperature `class-attribute` `instance-attribute`

    temperature: CPUTemperature = Field(
        MESSAGE, number=1, message=CPUTemperature
    )

### `` CalibratedImuTel

Calibrated IMU data.

#### `` imu `class-attribute` `instance-attribute`

    imu: Imu = Field(MESSAGE, number=1, message=Imu)

### `` CalibrationStateTel

Calibration state used for calibration routine.

#### `` calibration_state `class-attribute` `instance-attribute`

    calibration_state: CalibrationState = Field(
        MESSAGE, number=1, message=CalibrationState
    )

### `` CanisterBottomHumidityTel

Receive humidity information from the bottom canister.

#### `` humidity `class-attribute` `instance-attribute`

    humidity: CanisterHumidity = Field(
        MESSAGE, number=1, message=CanisterHumidity
    )

### `` CanisterBottomTemperatureTel

Receive temperature information from the bottom canister.

#### `` temperature `class-attribute` `instance-attribute`

    temperature: CanisterTemperature = Field(
        MESSAGE, number=1, message=CanisterTemperature
    )

### `` ConnectedClientsTel

List of connected clients telemetry message.

#### `` client_id_in_control `class-attribute` `instance-attribute`

    client_id_in_control: int = Field(UINT32, number=1)

#### `` connected_clients `class-attribute` `instance-attribute`

    connected_clients: MutableSequence[ConnectedClient] = (
        RepeatedField(
            MESSAGE, number=2, message=ConnectedClient
        )
    )

### `` ControlForceTel

Control force in all directions.

#### `` control_force `class-attribute` `instance-attribute`

    control_force: ControlForce = Field(
        MESSAGE, number=1, message=ControlForce
    )

### `` ControlModeTel

Receive the current state of the control system.

#### `` state `class-attribute` `instance-attribute`

    state: ControlMode = Field(
        MESSAGE, number=1, message=ControlMode
    )

### `` ControllerHealthTel

Controller health indicating the load of the controller, used to set a color in the heading and depth bar.

#### `` controller_health `class-attribute` `instance-attribute`

    controller_health: ControllerHealth = Field(
        MESSAGE, number=1, message=ControllerHealth
    )

### `` CpProbeTel

Cathodic Protection Potential probe telemetry message

#### `` cp_probe `class-attribute` `instance-attribute`

    cp_probe: CpProbe = Field(
        MESSAGE, number=1, message=CpProbe
    )

### `` DataStorageSpaceTel

Data storage info.

#### `` storage_space `class-attribute` `instance-attribute`

    storage_space: StorageSpace = Field(
        MESSAGE, number=1, message=StorageSpace
    )

### `` DepthTel

Measurement of the drones position relative to the sea surface.

#### `` depth `class-attribute` `instance-attribute`

    depth: Depth = Field(MESSAGE, number=1, message=Depth)

### `` DiveTimeTel

Receive the dive time of the drone.

#### `` dive_time `class-attribute` `instance-attribute`

    dive_time: DiveTime = Field(
        MESSAGE, number=1, message=DiveTime
    )

### `` DroneInfoTel

Receive metadata and information about the connected drone.

#### `` drone_info `class-attribute` `instance-attribute`

    drone_info: DroneInfo = Field(
        MESSAGE, number=1, message=DroneInfo
    )

### `` DroneTimeTel

Receive time information from the drone.

#### `` monotonic_clock `class-attribute` `instance-attribute`

    monotonic_clock: SystemTime = Field(
        MESSAGE, number=2, message=SystemTime
    )

#### `` real_time_clock `class-attribute` `instance-attribute`

    real_time_clock: SystemTime = Field(
        MESSAGE, number=1, message=SystemTime
    )

### `` DvlVelocityTel

Dvl raw sensor data.

#### `` dvl_velocity `class-attribute` `instance-attribute`

    dvl_velocity: DvlVelocity = Field(
        MESSAGE, number=1, message=DvlVelocity
    )

### `` ErrorFlagsTel

Receive currently set error flags.

#### `` error_flags `class-attribute` `instance-attribute`

    error_flags: ErrorFlags = Field(
        MESSAGE, number=1, message=ErrorFlags
    )

### `` ForwardDistanceTel

Distance to an object in front of the drone when a 1D pinger is mounted forwards.

#### `` forward_distance `class-attribute` `instance-attribute`

    forward_distance: ForwardDistance = Field(
        MESSAGE, number=1, message=ForwardDistance
    )

### `` GenericServoTel

State of a generic servo.

#### `` servo `class-attribute` `instance-attribute`

    servo: GenericServo = Field(
        MESSAGE, number=1, message=GenericServo
    )

### `` GuestPortCurrentTel

GuestPort current readings.

#### `` current `class-attribute` `instance-attribute`

    current: GuestPortCurrent = Field(
        MESSAGE, number=1, message=GuestPortCurrent
    )

### `` GuestPortLightsTel

Receive the status of any guest port lights connected to the drone.

#### `` lights `class-attribute` `instance-attribute`

    lights: Lights = Field(MESSAGE, number=1, message=Lights)

### `` Imu1Tel

Raw IMU data from IMU 1

#### `` imu `class-attribute` `instance-attribute`

    imu: Imu = Field(MESSAGE, number=1, message=Imu)

### `` Imu2Tel

Raw IMU data from IMU 2

#### `` imu `class-attribute` `instance-attribute`

    imu: Imu = Field(MESSAGE, number=1, message=Imu)

### `` IperfTel

Iperf indicates the available bandwidth on the tether from drone to surface unit.

#### `` status `class-attribute` `instance-attribute`

    status: IperfStatus = Field(
        MESSAGE, number=1, message=IperfStatus
    )

### `` LaserTel

Receive the status of any lasers connected to the drone.

#### `` laser `class-attribute` `instance-attribute`

    laser: Laser = Field(MESSAGE, number=1, message=Laser)

### `` LightsTel

Receive the status of the main lights of the drone.

#### `` lights `class-attribute` `instance-attribute`

    lights: Lights = Field(MESSAGE, number=1, message=Lights)

### `` MedusaSpectrometerDataTel

Medusa gamma ray sensor spectrometer data.

#### `` data `class-attribute` `instance-attribute`

    data: MedusaSpectrometerData = Field(
        MESSAGE, number=1, message=MedusaSpectrometerData
    )

### `` MissionStatusTel

Mission status from the mission supervisor.

#### `` mission_status `class-attribute` `instance-attribute`

    mission_status: MissionStatus = Field(
        MESSAGE, number=1, message=MissionStatus
    )

### `` MultibeamConfigTel

Multibeam sonar config.

#### `` config `class-attribute` `instance-attribute`

    config: MultibeamConfig = Field(
        MESSAGE, number=1, message=MultibeamConfig
    )

### `` MultibeamDiscoveryTel

Multibeam sonar status message.

#### `` discovery `class-attribute` `instance-attribute`

    discovery: MultibeamDiscovery = Field(
        MESSAGE, number=1, message=MultibeamDiscovery
    )

### `` MultibeamPingTel

Multibeam sonar ping data.

#### `` ping `class-attribute` `instance-attribute`

    ping: MultibeamPing = Field(
        MESSAGE, number=1, message=MultibeamPing
    )

### `` MultibeamServoTel

State of the servo installed in the multibeam.

#### `` servo `class-attribute` `instance-attribute`

    servo: MultibeamServo = Field(
        MESSAGE, number=1, message=MultibeamServo
    )

### `` NStreamersTel

Number of connected clients streaming video.

#### `` n_streamers `class-attribute` `instance-attribute`

    n_streamers: NStreamers = Field(
        MESSAGE, number=1, message=NStreamers
    )

### `` NotificationTel

Notification from the control system.

#### `` notification `class-attribute` `instance-attribute`

    notification: Notification = Field(
        MESSAGE, number=1, message=Notification
    )

### `` PilotGPSPositionTel

Pilot position (originating from device GPS) for logging.

#### `` position `class-attribute` `instance-attribute`

    position: LatLongPosition = Field(
        MESSAGE, number=1, message=LatLongPosition
    )

### `` PositionEstimateTel

Position estimate of the drone if a DVL or a positioning system is available.

#### `` position_estimate `class-attribute` `instance-attribute`

    position_estimate: PositionEstimate = Field(
        MESSAGE, number=1, message=PositionEstimate
    )

### `` RecordStateTel

Record state from the drone.

#### `` record_state `class-attribute` `instance-attribute`

    record_state: RecordState = Field(
        MESSAGE, number=1, message=RecordState
    )

### `` ReferenceAutoPilotTel

Reference for the auto pilot when a mission is active.

#### `` reference_auto_pilot `class-attribute` `instance-attribute`

    reference_auto_pilot: ReferenceAutoPilot = Field(
        MESSAGE, number=1, message=ReferenceAutoPilot
    )

### `` ReferenceTel

Reference signals indicating desired states.

#### `` reference `class-attribute` `instance-attribute`

    reference: Reference = Field(
        MESSAGE, number=1, message=Reference
    )

### `` ThicknessGaugeTel

Thickness gauge measurement telemetry message.

#### `` thickness_gauge `class-attribute` `instance-attribute`

    thickness_gauge: ThicknessGauge = Field(
        MESSAGE, number=1, message=ThicknessGauge
    )

### `` TiltAngleTel

Tilt angle state on main camera.

#### `` angle `class-attribute` `instance-attribute`

    angle: TiltAngle = Field(
        MESSAGE, number=1, message=TiltAngle
    )

### `` TiltStabilizationTel

Tilt stabilization state.

#### `` state `class-attribute` `instance-attribute`

    state: TiltStabilizationState = Field(
        MESSAGE, number=1, message=TiltStabilizationState
    )

### `` TimeLapseStateTel

Time-lapse state from the drone.

#### `` time_lapse_state `class-attribute` `instance-attribute`

    time_lapse_state: TimeLapseState = Field(
        MESSAGE, number=1, message=TimeLapseState
    )

### `` VideoStorageSpaceTel

Video storage info.

#### `` storage_space `class-attribute` `instance-attribute`

    storage_space: StorageSpace = Field(
        MESSAGE, number=1, message=StorageSpace
    )

### `` WaterTemperatureTel

Water temperature from the depth sensor.

#### `` temperature `class-attribute` `instance-attribute`

    temperature: WaterTemperature = Field(
        MESSAGE, number=1, message=WaterTemperature
    )